@@ -49,6 +49,7 @@ from openstack.identity.v3 import (
     role_system_user_assignment as _role_system_user_assignment,
 )
 from openstack.identity.v3 import service as _service
+from openstack.identity.v3 import service_provider as _service_provider
 from openstack.identity.v3 import system as _system
 from openstack.identity.v3 import trust as _trust
 from openstack.identity.v3 import user as _user
@@ -316,7 +317,7 @@ class Proxy(proxy.Proxy):
 
         :param domain_id: The value can be the ID of a domain or a
             :class:`~openstack.identity.v3.domain.Domain` instance.
-        :attrs kwargs: The attributes to update on the config for a domain
+        :param attrs: The attributes to update on the config for a domain
             represented by ``domain_id``.
 
         :returns: The updated config for a domain
@@ -1225,159 +1226,13 @@ class Proxy(proxy.Proxy):
         :param kwargs query: Optional query parameters to be sent to limit
             the resources being returned. The options
             are: group_id, role_id, scope_domain_id,
-            scope_project_id, user_id, include_names,
+            scope_project_id, inherited_to, user_id, include_names,
             include_subtree.
         :return:
             :class:`~openstack.identity.v3.role_assignment.RoleAssignment`
         """
         return self._list(_role_assignment.RoleAssignment, **query)
 
-    # ========== Registered limits ==========
-
-    def registered_limits(self, **query):
-        """Retrieve a generator of registered_limits
-
-        :param kwargs query: Optional query parameters to be sent to limit
-            the registered_limits being returned.
-
-        :returns: A generator of registered_limits instances.
-        :rtype: :class:
-            `~openstack.identity.v3.registered_limit.RegisteredLimit`
-        """
-        return self._list(_registered_limit.RegisteredLimit, **query)
-
-    def get_registered_limit(self, registered_limit):
-        """Get a single registered_limit
-
-        :param registered_limit: The value can be the ID of a registered_limit
-            or a :class:
-            `~openstack.identity.v3.registered_limit.RegisteredLimit` instance.
-
-        :returns: One :class:
-            `~openstack.identity.v3.registered_limit.RegisteredLimit`
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
-            when no resource can be found.
-        """
-        return self._get(_registered_limit.RegisteredLimit, registered_limit)
-
-    def create_registered_limit(self, **attrs):
-        """Create a new registered_limit from attributes
-
-        :param dict attrs: Keyword arguments which will be used to create a
-            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`,
-            comprised of the properties on the RegisteredLimit class.
-
-        :returns: The results of registered_limit creation.
-        :rtype: :class:
-            `~openstack.identity.v3.registered_limit.RegisteredLimit`
-        """
-        return self._create(_registered_limit.RegisteredLimit, **attrs)
-
-    def update_registered_limit(self, registered_limit, **attrs):
-        """Update a registered_limit
-
-        :param registered_limit: Either the ID of a registered_limit. or a
-            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
-            instance.
-        :param dict kwargs: The attributes to update on the registered_limit
-            represented by ``value``.
-
-        :returns: The updated registered_limit.
-        :rtype: :class:
-            `~openstack.identity.v3.registered_limit.RegisteredLimit`
-        """
-        return self._update(
-            _registered_limit.RegisteredLimit, registered_limit, **attrs
-        )
-
-    def delete_registered_limit(self, registered_limit, ignore_missing=True):
-        """Delete a registered_limit
-
-        :param registered_limit: The value can be either the ID of a
-            registered_limit or a
-            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
-            instance.
-        :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
-            the registered_limit does not exist. When set to ``True``, no
-            exception will be thrown when attempting to delete a nonexistent
-            registered_limit.
-
-        :returns: ``None``
-        """
-        self._delete(
-            _registered_limit.RegisteredLimit,
-            registered_limit,
-            ignore_missing=ignore_missing,
-        )
-
-    # ========== Limits ==========
-
-    def limits(self, **query):
-        """Retrieve a generator of limits
-
-        :param kwargs query: Optional query parameters to be sent to limit
-            the limits being returned.
-
-        :returns: A generator of limits instances.
-        :rtype: :class:`~openstack.identity.v3.limit.Limit`
-        """
-        return self._list(_limit.Limit, **query)
-
-    def get_limit(self, limit):
-        """Get a single limit
-
-        :param limit: The value can be the ID of a limit
-            or a :class:`~openstack.identity.v3.limit.Limit` instance.
-
-        :returns: One :class:
-            `~openstack.identity.v3.limit.Limit`
-        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
-            resource can be found.
-        """
-        return self._get(_limit.Limit, limit)
-
-    def create_limit(self, **attrs):
-        """Create a new limit from attributes
-
-        :param dict attrs: Keyword arguments which will be used to create
-            a :class:`~openstack.identity.v3.limit.Limit`, comprised of the
-            properties on the Limit class.
-
-        :returns: The results of limit creation.
-        :rtype: :class:`~openstack.identity.v3.limit.Limit`
-        """
-        return self._create(_limit.Limit, **attrs)
-
-    def update_limit(self, limit, **attrs):
-        """Update a limit
-
-        :param limit: Either the ID of a limit. or a
-            :class:`~openstack.identity.v3.limit.Limit` instance.
-        :param dict kwargs: The attributes to update on the limit represented
-            by ``value``.
-
-        :returns: The updated limit.
-        :rtype: :class:`~openstack.identity.v3.limit.Limit`
-        """
-        return self._update(_limit.Limit, limit, **attrs)
-
-    def delete_limit(self, limit, ignore_missing=True):
-        """Delete a limit
-
-        :param limit: The value can be either the ID of a limit or a
-            :class:`~openstack.identity.v3.limit.Limit` instance.
-        :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
-            the limit does not exist. When set to ``True``, no exception will
-            be thrown when attempting to delete a nonexistent limit.
-
-        :returns: ``None``
-        """
-        self._delete(limit.Limit, limit, ignore_missing=ignore_missing)
-
-    # ========== Roles ==========
-
     def assign_domain_role_to_user(self, domain, user, role):
         """Assign role to user on a domain
 
@@ -1666,6 +1521,147 @@ class Proxy(proxy.Proxy):
         system = self._get_resource(_system.System, system)
         return system.validate_group_has_role(self, group, role)
 
+    # ========== Registered limits ==========
+
+    def registered_limits(self, **query):
+        """Retrieve a generator of registered_limits
+
+        :param kwargs query: Optional query parameters to be sent to limit
+            the registered_limits being returned.
+
+        :returns: A generator of registered_limits instances.
+        :rtype: :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
+        """
+        return self._list(_registered_limit.RegisteredLimit, **query)
+
+    def get_registered_limit(self, registered_limit):
+        """Get a single registered_limit
+
+        :param registered_limit: The value can be the ID of a registered_limit
+            or a
+            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
+            instance.
+
+        :returns: One :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+            when no resource can be found.
+        """
+        return self._get(_registered_limit.RegisteredLimit, registered_limit)
+
+    def create_registered_limit(self, **attrs):
+        """Create a new registered_limit from attributes
+
+        :param dict attrs: Keyword arguments which will be used to create a
+            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`,
+            comprised of the properties on the RegisteredLimit class.
+
+        :returns: The results of registered_limit creation.
+        :rtype: :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
+        """
+        return self._create(_registered_limit.RegisteredLimit, **attrs)
+
+    def update_registered_limit(self, registered_limit, **attrs):
+        """Update a registered_limit
+
+        :param registered_limit: Either the ID of a registered_limit. or a
+            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
+            instance.
+        :param dict kwargs: The attributes to update on the registered_limit
+            represented by ``value``.
+
+        :returns: The updated registered_limit.
+        :rtype:
+            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
+        """
+        return self._update(
+            _registered_limit.RegisteredLimit, registered_limit, **attrs
+        )
+
+    def delete_registered_limit(self, registered_limit, ignore_missing=True):
+        """Delete a registered_limit
+
+        :param registered_limit: The value can be either the ID of a
+            registered_limit or a
+            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
+            instance.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the registered_limit does not exist. When set to ``True``, no
+            exception will be thrown when attempting to delete a nonexistent
+            registered_limit.
+
+        :returns: ``None``
+        """
+        self._delete(
+            _registered_limit.RegisteredLimit,
+            registered_limit,
+            ignore_missing=ignore_missing,
+        )
+
+    # ========== Limits ==========
+
+    def limits(self, **query):
+        """Retrieve a generator of limits
+
+        :param kwargs query: Optional query parameters to be sent to limit
+            the limits being returned.
+
+        :returns: A generator of limits instances.
+        :rtype: :class:`~openstack.identity.v3.limit.Limit`
+        """
+        return self._list(_limit.Limit, **query)
+
+    def get_limit(self, limit):
+        """Get a single limit
+
+        :param limit: The value can be the ID of a limit
+            or a :class:`~openstack.identity.v3.limit.Limit` instance.
+
+        :returns: One :class:`~openstack.identity.v3.limit.Limit`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        return self._get(_limit.Limit, limit)
+
+    def create_limit(self, **attrs):
+        """Create a new limit from attributes
+
+        :param dict attrs: Keyword arguments which will be used to create
+            a :class:`~openstack.identity.v3.limit.Limit`, comprised of the
+            properties on the Limit class.
+
+        :returns: The results of limit creation.
+        :rtype: :class:`~openstack.identity.v3.limit.Limit`
+        """
+        return self._create(_limit.Limit, **attrs)
+
+    def update_limit(self, limit, **attrs):
+        """Update a limit
+
+        :param limit: Either the ID of a limit. or a
+            :class:`~openstack.identity.v3.limit.Limit` instance.
+        :param dict kwargs: The attributes to update on the limit represented
+            by ``value``.
+
+        :returns: The updated limit.
+        :rtype: :class:`~openstack.identity.v3.limit.Limit`
+        """
+        return self._update(_limit.Limit, limit, **attrs)
+
+    def delete_limit(self, limit, ignore_missing=True):
+        """Delete a limit
+
+        :param limit: The value can be either the ID of a limit or a
+            :class:`~openstack.identity.v3.limit.Limit` instance.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the limit does not exist. When set to ``True``, no exception will
+            be thrown when attempting to delete a nonexistent limit.
+
+        :returns: ``None``
+        """
+        self._delete(_limit.Limit, limit, ignore_missing=ignore_missing)
+
     # ========== Application credentials ==========
 
     def application_credentials(self, user, **query):
@@ -1695,9 +1691,9 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.identity.v3.user.User` instance.
 
         :param application_credential: The value can be the ID of a
-            application credential or a :class:
-            `~openstack.identity.v3.application_credential.
-            ApplicationCredential` instance.
+            application credential or a
+            :class:`~openstack.identity.v3.application_credential.ApplicationCredential`
+            instance.
 
         :returns: One
             :class:`~openstack.identity.v3.application_credential.ApplicationCredential`
@@ -2136,8 +2132,8 @@ class Proxy(proxy.Proxy):
     def access_rules(self, user, **query):
         """Retrieve a generator of access rules
 
-        :param user: Either the ID of a user or a :class:`~.user.User`
-            instance.
+        :param user: Either the ID of a user or a
+            :class:`~openstack.identity.v3.user.User` instance.
         :param kwargs query: Optional query parameters to be sent to
             limit the resources being returned.
 
@@ -2150,8 +2146,8 @@ class Proxy(proxy.Proxy):
     def get_access_rule(self, user, access_rule):
         """Get a single access rule
 
-        :param user: Either the ID of a user or a :class:`~.user.User`
-            instance.
+        :param user: Either the ID of a user or a
+            :class:`~openstack.identity.v3.user.User` instance.
         :param access rule: The value can be the ID of an access rule or a
             :class:`~.access_rule.AccessRule` instance.
 
@@ -2165,8 +2161,8 @@ class Proxy(proxy.Proxy):
     def delete_access_rule(self, user, access_rule, ignore_missing=True):
         """Delete an access rule
 
-        :param user: Either the ID of a user or a :class:`~.user.User`
-            instance.
+        :param user: Either the ID of a user or a
+            :class:`~openstack.identity.v3.user.User` instance.
         :param access rule: The value can be either the ID of an
             access rule or a :class:`~.access_rule.AccessRule` instance.
         :param bool ignore_missing: When set to ``False``
@@ -2183,3 +2179,102 @@ class Proxy(proxy.Proxy):
             user_id=user.id,
             ignore_missing=ignore_missing,
         )
+
+    # ========== Service providers ==========
+
+    def create_service_provider(self, **attrs):
+        """Create a new service provider from attributes
+
+        :param dict attrs: Keyword arguments which will be used to create a
+            :class:`~openstack.identity.v3.service_provider.ServiceProvider`,
+            comprised of the properties on the ServiceProvider class.
+
+        :returns: The results of service provider creation
+        :rtype:
+            :class:`~openstack.identity.v3.service_provider.ServiceProvider`
+        """
+        return self._create(_service_provider.ServiceProvider, **attrs)
+
+    def delete_service_provider(self, service_provider, ignore_missing=True):
+        """Delete a service provider
+
+        :param service_provider: The ID of a service provider or a
+            :class:`~openstack.identity.v3.service_provider.ServiceProvider`
+            instance.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the service provider does not exist.
+            When set to ``True``, no exception will be set when
+            attempting to delete a nonexistent service provider.
+
+        :returns: ``None``
+        """
+        self._delete(
+            _service_provider.ServiceProvider,
+            service_provider,
+            ignore_missing=ignore_missing,
+        )
+
+    def find_service_provider(self, name_or_id, ignore_missing=True):
+        """Find a single service provider
+
+        :param name_or_id: The name or ID of a service provider
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the resource does not exist. When set to ``True``, None will be
+            returned when attempting to find a nonexistent resource.
+
+        :returns: The details of an service provider or None.
+        :rtype:
+            :class:`~openstack.identity.v3.service_provider.ServiceProvider`
+        """
+        return self._find(
+            _service_provider.ServiceProvider,
+            name_or_id,
+            ignore_missing=ignore_missing,
+        )
+
+    def get_service_provider(self, service_provider):
+        """Get a single service provider
+
+        :param service_provider: The value can be the ID of a service provider
+            or a
+            :class:`~openstack.identity.v3.server_provider.ServiceProvider`
+            instance.
+
+        :returns: The details of an service provider.
+        :rtype:
+            :class:`~openstack.identity.v3.service_provider.ServiceProvider`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+            when no resource can be found.
+        """
+        return self._get(_service_provider.ServiceProvider, service_provider)
+
+    def service_providers(self, **query):
+        """Retrieve a generator of service providers
+
+        :param kwargs query: Optional query parameters to be sent to limit
+            the resources being returned.
+
+        :returns: A generator of service provider instances.
+        :rtype:
+            :class:`~openstack.identity.v3.service_provider.ServiceProvider`
+        """
+        return self._list(_service_provider.ServiceProvider, **query)
+
+    def update_service_provider(self, service_provider, **attrs):
+        """Update a service provider
+
+        :param service_provider: Either the ID of an service provider or a
+            :class:`~openstack.identity.v3.service_provider.ServiceProvider`
+            instance.
+        :param attrs: The attributes to update on the service provider
+            represented by ``service_provider``.
+
+        :returns: The updated service provider.
+        :rtype:
+            :class:`~openstack.identity.v3.service_provider.ServiceProvider`
+        """
+        return self._update(
+            _service_provider.ServiceProvider, service_provider, **attrs
+        )
