@@ -16,6 +16,8 @@ from openstack.shared_file_system.v2 import (
     availability_zone as _availability_zone,
 )
 from openstack.shared_file_system.v2 import limit as _limit
+from openstack.shared_file_system.v2 import quota_class_set as _quota_class_set
+from openstack.shared_file_system.v2 import resource_locks as _resource_locks
 from openstack.shared_file_system.v2 import share as _share
 from openstack.shared_file_system.v2 import share_group as _share_group
 from openstack.shared_file_system.v2 import (
@@ -56,6 +58,8 @@ class Proxy(proxy.Proxy):
         "share_access_rule": _share_access_rule.ShareAccessRule,
         "share_group": _share_group.ShareGroup,
         "share_group_snapshot": _share_group_snapshot.ShareGroupSnapshot,
+        "resource_locks": _resource_locks.ResourceLock,
+        "quota_class_set": _quota_class_set.QuotaClassSet,
     }
 
     def availability_zones(self):
@@ -354,7 +358,13 @@ class Proxy(proxy.Proxy):
         )
 
     def wait_for_status(
-        self, res, status='active', failures=None, interval=2, wait=120
+        self,
+        res,
+        status='active',
+        failures=None,
+        interval=2,
+        wait=120,
+        status_attr_name='status',
     ):
         """Wait for a resource to be in a particular status.
         :param res: The resource to wait on to reach the specified status.
@@ -367,6 +377,8 @@ class Proxy(proxy.Proxy):
             checks. Default to 2.
         :param wait: Maximum number of seconds to wait before the change.
             Default to 120.
+        :param status_attr_name: name of the attribute to reach the desired
+            status.
         :returns: The resource is returned on success.
         :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
             to the desired status failed to occur in specified seconds.
@@ -377,7 +389,13 @@ class Proxy(proxy.Proxy):
         """
         failures = [] if failures is None else failures
         return resource.wait_for_status(
-            self, res, status, failures, interval, wait
+            self,
+            res,
+            status,
+            failures,
+            interval,
+            wait,
+            attribute=status_attr_name,
         )
 
     def storage_pools(self, details=True, **query):
@@ -578,7 +596,7 @@ class Proxy(proxy.Proxy):
         return self._create(
             _share_network_subnet.ShareNetworkSubnet,
             **attrs,
-            share_network_id=share_network_id
+            share_network_id=share_network_id,
         )
 
     def delete_share_network_subnet(
@@ -638,7 +656,7 @@ class Proxy(proxy.Proxy):
         return self._list(
             _share_snapshot_instance.ShareSnapshotInstance,
             base_path=base_path,
-            **query
+            **query,
         )
 
     def get_share_snapshot_instance(self, snapshot_instance_id):
@@ -841,22 +859,30 @@ class Proxy(proxy.Proxy):
         :rtype: :class:`~openstack.shared_file_system.v2.
             share_access_rules.ShareAccessRules`
         """
-        base_path = "/shares/%s/action" % (share_id,)
+        base_path = f"/shares/{share_id}/action"
         return self._create(
             _share_access_rule.ShareAccessRule, base_path=base_path, **attrs
         )
 
-    def delete_access_rule(self, access_id, share_id, ignore_missing=True):
+    def delete_access_rule(
+        self, access_id, share_id, ignore_missing=True, *, unrestrict=False
+    ):
         """Deletes an access rule
 
         :param access_id: The id of the access rule to get
         :param share_id: The ID of the share
+        :param unrestrict: If Manila must attempt removing locks while deleting
 
         :rtype: ``requests.models.Response`` HTTP response from internal
             requests client
         """
         res = self._get_resource(_share_access_rule.ShareAccessRule, access_id)
-        res.delete(self, share_id, ignore_missing=ignore_missing)
+        return res.delete(
+            self,
+            share_id,
+            ignore_missing=ignore_missing,
+            unrestrict=unrestrict,
+        )
 
     def share_group_snapshots(self, details=True, **query):
         """Lists all share group snapshots.
@@ -887,7 +913,7 @@ class Proxy(proxy.Proxy):
         return self._list(
             _share_group_snapshot.ShareGroupSnapshot,
             base_path=base_path,
-            **query
+            **query,
         )
 
     def share_group_snapshot_members(self, group_snapshot_id):
@@ -932,7 +958,7 @@ class Proxy(proxy.Proxy):
         return self._create(
             _share_group_snapshot.ShareGroupSnapshot,
             share_group_id=share_group_id,
-            **attrs
+            **attrs,
         )
 
     def reset_share_group_snapshot_status(self, group_snapshot_id, status):
@@ -961,7 +987,7 @@ class Proxy(proxy.Proxy):
         return self._update(
             _share_group_snapshot.ShareGroupSnapshot,
             group_snapshot_id,
-            **attrs
+            **attrs,
         )
 
     def delete_share_group_snapshot(
@@ -1065,3 +1091,135 @@ class Proxy(proxy.Proxy):
             raise exceptions.SDKException(
                 "Some keys failed to be deleted %s" % keys_failed_to_delete
             )
+
+    def resource_locks(self, **query):
+        """Lists all resource locks.
+
+        :param kwargs query: Optional query parameters to be sent to limit
+            the resource locks being returned.  Available parameters include:
+
+            * project_id: The project ID of the user that the lock is
+                created for.
+            * user_id: The ID of a user to filter resource locks by.
+            * all_projects: list locks from all projects (Admin Only)
+            * resource_id: The ID of the resource that the locks pertain to
+                filter resource locks by.
+            * resource_action: The action prevented by the filtered resource
+                locks.
+            * resource_type: The type of the resource that the locks pertain
+                to filter resource locks by.
+            * lock_context: The lock creator’s context to filter locks by.
+            * lock_reason: The lock reason that can be used to filter resource
+                locks. (Inexact search is also available with lock_reason~)
+            * created_since: Search for the list of resources that were created
+                after the specified date. The date is in ‘yyyy-mm-dd’ format.
+            * created_before: Search for the list of resources that were
+                created prior to the specified date. The date is in
+                ‘yyyy-mm-dd’ format.
+            * limit: The maximum number of resource locks to return.
+            * offset: The offset to define start point of resource lock
+                listing.
+            * sort_key: The key to sort a list of shares.
+            * sort_dir: The direction to sort a list of shares
+            * with_count: Whether to show count in API response or not,
+                default is False. This query parameter is useful with
+                pagination.
+
+        :returns: A generator of manila resource locks
+        :rtype: :class:`~openstack.shared_file_system.v2.
+            resource_locks.ResourceLock`
+        """
+        return self._list(_resource_locks.ResourceLock, **query)
+
+    def get_resource_lock(self, resource_lock):
+        """Show details of a resource lock.
+
+        :param resource_lock: The ID of a resource lock or a
+            :class:`~openstack.shared_file_system.v2.
+            resource_locks.ResourceLock` instance.
+        :returns: Details of the identified resource lock.
+        :rtype: :class:`~openstack.shared_file_system.v2.
+            resource_locks.ResourceLock`
+        """
+        return self._get(_resource_locks.ResourceLock, resource_lock)
+
+    def update_resource_lock(self, resource_lock, **attrs):
+        """Updates details of a single resource lock.
+
+        :param resource_lock: The ID of a resource lock or a
+            :class:`~openstack.shared_file_system.v2.
+            resource_locks.ResourceLock` instance.
+        :param dict attrs: The attributes to update on the resource lock
+        :returns: the updated resource lock
+        :rtype: :class:`~openstack.shared_file_system.v2.
+            resource_locks.ResourceLock`
+        """
+        return self._update(
+            _resource_locks.ResourceLock, resource_lock, **attrs
+        )
+
+    def delete_resource_lock(self, resource_lock, ignore_missing=True):
+        """Deletes a single resource lock
+
+        :param resource_lock: The ID of a resource lock or a
+            :class:`~openstack.shared_file_system.v2.
+            resource_locks.ResourceLock` instance.
+        :returns: Result of the ``delete``
+        :rtype: ``None``
+        """
+        return self._delete(
+            _resource_locks.ResourceLock,
+            resource_lock,
+            ignore_missing=ignore_missing,
+        )
+
+    def create_resource_lock(self, **attrs):
+        """Locks a resource.
+
+        :param dict attrs: Attributes which will be used to create
+            a :class:`~openstack.shared_file_system.v2.
+            resource_locks.ResourceLock`, comprised of the properties
+            on the ResourceLock class. Available parameters include:
+
+            * ``resource_id``: ID of the resource to be locked.
+            * ``resource_type``: type of the resource (share, access_rule).
+            * ``resource_action``: action to be locked (delete, show).
+            * ``lock_reason``: reason why you're locking the resource
+                (Optional).
+        :returns: Details of the lock
+        :rtype: :class:`~openstack.shared_file_system.v2.
+            resource_locks.ResourceLock`
+        """
+
+        if attrs.get('resource_type'):
+            # The _create method has a parameter named resource_type, which
+            # refers to the type of resource to be created, so we need to avoid
+            # a conflict of parameters we are sending to the method.
+            attrs['__conflicting_attrs'] = {
+                'resource_type': attrs.get('resource_type')
+            }
+            attrs.pop('resource_type')
+        return self._create(_resource_locks.ResourceLock, **attrs)
+
+    def get_quota_class_set(self, quota_class_name):
+        """Get quota class set.
+
+        :param quota_class_name: The name of the quota class
+        :returns: A :class:`~openstack.shared_file_system.v2
+            .quota_class_set.QuotaClassSet`
+        """
+        return self._get(_quota_class_set.QuotaClassSet, quota_class_name)
+
+    def update_quota_class_set(self, quota_class_name, **attrs):
+        """Update quota class set.
+
+        :param quota_class_name: The name of the quota class
+        :param attrs: The attributes to update on the quota class set
+        :returns: the updated quota class set
+        :rtype: :class:`~openstack.shared_file_system.v2
+            .quota_class_set.QuotaClassSet`
+        """
+
+        return self._update(
+            _quota_class_set.QuotaClassSet, quota_class_name, **attrs
+        )
