@@ -33,13 +33,12 @@ from openstack.tests.functional import base
 
 class TestFloatingIPPool(base.BaseFunctionalTest):
     def setUp(self):
-        super(TestFloatingIPPool, self).setUp()
+        super().setUp()
 
         if not self.user_cloud._has_nova_extension('os-floating-ip-pools'):
             # Skipping this test is floating-ip-pool extension is not
             # available on the testing cloud
-            self.skip(
-                'Floating IP pools extension is not available')
+            self.skip('Floating IP pools extension is not available')
 
     def test_list_floating_ip_pools(self):
         pools = self.user_cloud.list_floating_ip_pools()
