@@ -14,16 +14,15 @@
 test_magnum_services
 --------------------
 
-Functional tests for `shade` services method.
+Functional tests for services method.
 """
 
 from openstack.tests.functional import base
 
 
 class TestMagnumServices(base.BaseFunctionalTest):
-
     def setUp(self):
-        super(TestMagnumServices, self).setUp()
+        super().setUp()
         if not self.user_cloud.has_service(
             'container-infrastructure-management'
         ):
