@@ -34,6 +34,7 @@ EXAMPLE = {
     'dns_name': '12',
     'extra_dhcp_opts': [{'13': 13}],
     'fixed_ips': [{'14': '14'}],
+    'hardware_offload_type': None,
     'id': IDENTIFIER,
     'ip_allocation': 'immediate',
     'mac_address': '16',
@@ -112,6 +113,8 @@ class TestPort(base.TestCase):
                 "not_any_tags": "not-tags-any",
                 "not_tags": "not-tags",
                 "tags": "tags",
+                'sort_dir': 'sort_dir',
+                'sort_key': 'sort_key',
             },
             sot._query_mapping._mapping,
         )
